import unittest
from results import *
from sportinf.parse_information import SportInfo


class OptionsTests(unittest.TestCase):
    def test_info_team(self):
        self.maxDiff = None
        test_case = SportInfo(option="Information about team", team_name="Arsenal")
        self.assertEqual(test_case.sport_info(), result_info_team)

    def test_info_player(self):
        self.maxDiff = None
        test_case = SportInfo(option="Information about player", player_name="Lionel Messi")
        self.assertEqual(test_case.sport_info(), result_info_player)

    def test_info_event(self):
        self.maxDiff = None
        test_case = SportInfo(option="Information about event", event_name="Arsenal vs Chelsea")
        self.assertEqual(test_case.sport_info(), result_info_event)

    def test_all_sports(self):
        self.maxDiff = None
        test_case = SportInfo(option="List all sports")
        self.assertEqual(test_case.sport_info(), result_all_sports)

    def test_all_leagues(self):
        self.maxDiff = None
        test_case = SportInfo(option="List all leagues")
        self.assertEqual(test_case.sport_info(), result_all_leagues)

    def test_all_countries(self):
        self.maxDiff = None
        test_case = SportInfo(option="List all countries")
        self.assertEqual(test_case.sport_info(), result_all_countries)

    def test_all_seasons(self):
        self.maxDiff = None
        test_case = SportInfo(option="List all Seasons in a League", league_name="English Premier League")
        self.assertEqual(test_case.sport_info(), result_all_seasons)

    def test_all_teams(self):
        self.maxDiff = None
        test_case = SportInfo(option="List all Teams in a League", league_name="English Premier League")
        self.assertEqual(test_case.sport_info(), result_all_teams)

    def test_league_details(self):
        self.maxDiff = None
        test_case = SportInfo(option="League Details", league_name="English Premier League")
        self.assertEqual(test_case.sport_info(), result_league_details)

    def test_honours(self):
        self.maxDiff = None
        test_case = SportInfo(option="Player Honours", player_name="Lionel Messi")
        self.assertEqual(test_case.sport_info(), result_honours)

    def test_former_teams(self):
        self.maxDiff = None
        test_case = SportInfo(option="Player Former Teams", player_name="Lionel Messi")
        self.assertEqual(test_case.sport_info(), result_former_teams)

    def test_contracts(self):
        self.maxDiff = None
        test_case = SportInfo(option="Player Contracts", player_name="Lionel Messi")
        self.assertEqual(test_case.sport_info(), result_contracts)

    def test_table(self):
        self.maxDiff = None
        test_case = SportInfo(option="Lookup Table by League and Season", league_name="English Premier League", season="2020-2021")
        self.assertEqual(test_case.sport_info(), result_table)

    def test_equipment(self):
        self.maxDiff = None
        test_case = SportInfo(option="Lookup Equipment by Team", team_name="Arsenal")
        self.assertEqual(test_case.sport_info(), result_equipment)

    def test_15_events(self):
        self.maxDiff = None
        test_case = SportInfo(option="Last 15 Events by League", league_name="English Premier League")
        self.assertEqual(test_case.sport_info(), result_15_events)


if __name__ == '__main__':
    unittest.main()



"""
link_patterns is a dictionary that contains
"""
link_patterns = {
    "Information about team":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/searchteams.php?t={parameter1}",
            "parameter1": "team_name",
            "useful parameters": ["strTeam", "strTeamShort", "strAlternate", "intFormedYear", "strSport", "strLeague",
                                  "strLeague2", "strLeague3", "strLeague4", "strLeague5", "strLeague6", "strLeague7",
                                  "strDivision", "strManager", "strStadium", "strKeywords", "strRSS", "strStadiumThumb",
                                  "strStadiumDescription", "strStadiumLocation", "intStadiumCapacity", "strWebsite",
                                  "strFacebook", "strTwitter", "strInstagram", "strDescriptionEN", "strDescriptionDE",
                                  "strDescriptionFR", "strDescriptionCN", "strDescriptionIT", "strDescriptionJP",
                                  "strDescriptionRU", "strDescriptionES", "strDescriptionPT", "strDescriptionSE",
                                  "strDescriptionNL", "strDescriptionHU", "strDescriptionNO", "strDescriptionIL",
                                  "strDescriptionPL", "strGender", "strCountry", "strTeamBadge", "strTeamJersey",
                                  "strTeamLogo", "strTeamFanart1", "strTeamFanart2", "strTeamFanart3", "strTeamFanart4",
                                  "strTeamBanner", "strYoutube"]
        },  # team name----------------------------------------
    # "strRSS", "strStadiumThumb",
    "Information about player":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/searchplayers.php?p={parameter1}",
            "parameter1": "player_name",
            "useful parameters": ["strPlayer", "strNationality", "strTeam", "strTeam2", "strSport", "dateBorn",
                                  "strNumber", "dateSigned", "strSigning", "strWage", "strOutfitter", "strKit",
                                  "strAgent", "strBirthLocation", "strDescriptionEN", "strDescriptionDE",
                                  "strDescriptionFR", "strDescriptionCN", "strDescriptionIT", "strDescriptionJP",
                                  "strDescriptionRU", "strDescriptionES", "strDescriptionPT", "strDescriptionSE",
                                  "strDescriptionNL", "strDescriptionHU", "strDescriptionNO", "strDescriptionIL",
                                  "strDescriptionPL", "strGender", "strSide", "strPosition", "strCollege",
                                  "strFacebook", "strWebsite", "strTwitter", "strInstagram", "strYoutube", "strHeight",
                                  "strWeight", "strThumb", "strCutout", "strRender", "strBanner", "strFanart1",
                                  "strFanart2", "strFanart3", "strFanart4"]
        },  # player name----------------------------------------------------------
    "Information about event":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/searchevents.php?e={parameter1}",
            "parameter1": "event_name",
            "useful parameters": ["dateEvent", "strEvent", "strEventAlternate", "strFilename", "strSport", "strLeague",
                                  "strSeason", "strDescriptionEN", "strHomeTeam", "strAwayTeam", "intHomeScore",
                                  "intRound", "intAwayScore", "intSpectators", "strOfficial", "strHomeGoalDetails",
                                  "strHomeRedCards", "strHomeYellowCards", "strHomeLineupGoalkeeper",
                                  "strHomeLineupDefense", "strHomeLineupMidfield", "strHomeLineupForward",
                                  "strHomeLineupSubstitutes", "strHomeFormation", "strAwayRedCards",
                                  "strAwayYellowCards", "strAwayGoalDetails", "strAwayLineupGoalkeeper",
                                  "strAwayLineupDefense", "strAwayLineupMidfield", "strAwayLineupForward",
                                  "strAwayLineupSubstitutes", "strAwayFormation", "intHomeShots", "intAwayShots",
                                  "strTimestamp", "dateEventLocal", "strTime", "strTimeLocal",
                                  "strTVStation", "strResult", "strVenue", "strCountry", "strCity", "strPoster",
                                  "strSquare", "strFanart", "strThumb", "strBanner", "strMap", "strTweet1", "strTweet2",
                                  "strTweet3", "strVideo", "strStatus", "strPostponed"]
        },  # event name
    "List all sports":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/all_sports.php",
            "useful parameters": ["strSport", "strFormat", "strSportThumb", "strSportThumbGreen", "strSportDescription"]
        },
    "List all leagues":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/all_leagues.php",
            "useful parameters": ["strLeague", "strSport", "strLeagueAlternate"]
        },
    "List all countries":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/all_countries.php",
            "useful parameters": ["name_en"]
        },
    # "List all Leagues in a country": "",
    "List all Seasons in a League":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/search_all_seasons.php?id={parameter1}",
            "parameter1": "league_name",
            "useful parameters": ["strSeason"]
        },  # league ID
    "List all Teams in a League":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/search_all_teams.php?l={parameter1}",
            "parameter1": "league_name",
            "useful parameters": ["strTeam", "strTeamShort", "strAlternate", "intFormedYear", "strSport", "strLeague",
                                  "strLeague2", "strLeague3", "strLeague4", "strLeague5", "strLeague6", "strLeague7",
                                  "strDivision", "strManager", "strStadium", "strKeywords", "strRSS", "strStadiumThumb",
                                  "strStadiumDescription", "strStadiumLocation", "intStadiumCapacity", "strWebsite",
                                  "strFacebook", "strTwitter", "strInstagram", "strDescriptionEN", "strDescriptionDE",
                                  "strDescriptionFR", "strDescriptionCN", "strDescriptionIT", "strDescriptionJP",
                                  "strDescriptionRU", "strDescriptionES", "strDescriptionPT", "strDescriptionSE",
                                  "strDescriptionNL", "strDescriptionHU", "strDescriptionNO", "strDescriptionIL",
                                  "strDescriptionPL", "strGender", "strCountry", "strTeamBadge", "strTeamJersey",
                                  "strTeamLogo", "strTeamFanart1", "strTeamFanart2", "strTeamFanart3", "strTeamFanart4",
                                  "strTeamBanner", "strYoutube"]
        },  # league name, use for loop-------------------------------------
    "League Details":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/lookupleague.php?id={parameter1}",
            "parameter1": "league_name",
            "useful parameters": ["strLeague", "strSport", "strLeagueAlternate", "strDivision", "strCurrentSeason",
                                  "intFormedYear", "dateFirstEvent", "strGender", "strCountry", "strWebsite",
                                  "strFacebook", "strTwitter", "strYoutube", "strRSS", "strDescriptionEN",
                                  "strDescriptionDE", "strDescriptionFR", "strDescriptionIT", "strDescriptionCN",
                                  "strDescriptionJP", "strDescriptionRU", "strDescriptionES", "strDescriptionPT",
                                  "strDescriptionSE", "strDescriptionNL", "strDescriptionHU", "strDescriptionNO",
                                  "strDescriptionPL", "strDescriptionIL", "strTvRights", "strFanart1", "strFanart2",
                                  "strFanart3", "strFanart4", "strBanner", "strBadge", "strLogo", "strPoster",
                                  "strTrophy", "strNaming"]
        },  # league ID
    "Player Honours":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/lookuphonors.php?id={parameter1}",
            "parameter1": "player_name",
            "useful parameters": ["strHonour", "strPlayer", "strSport", "strTeam", "strSeason"]
        },  # player ID
    "Player Former Teams":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/lookupformerteams.php?id={parameter1}",
            "parameter1": "player_name",
            "useful parameters": ["strFormerTeam", "strSport", "strPlayer", "strMoveType", "strTeamBadge", "strJoined",
                                  "strDeparted"]
        },  # player ID
    "Player Contracts":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/lookupcontracts.php?id={parameter1}",
            "parameter1": "player_name",
            "useful parameters": ["strSport", "strPlayer", "strTeam", "strTeamBadge", "strYearStart", "strYearEnd",
                                  "strWage"]
        },  # player ID-----------------------------------------------------------------
    "Lookup Table by League and Season":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/lookuptable.php?l={parameter1}&s={parameter2}",
            "parameter1": "league_name",
            "parameter2": "season",
            "useful parameters": ["intRank", "strTeam", "strTeamBadge", "strLeague", "strSeason", "strForm",
                                  "strDescription", "intPlayed", "intWin", "intLoss", "intDraw", "intGoalsFor",
                                  "intGoalsAgainst", "intGoalDifference", "intPoints", "dateUpdated"]
        },  # league ID and season----------------------------------------------
    "Lookup Equipment by Team":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/lookupequipment.php?id={parameter1}",
            "parameter1": "team_name",
            "useful parameters": ["date", "strSeason", "strEquipment", "strType", "strUsername"]
        },  # team ID------------------------------------------
    "Last 15 Events by League":
        {
            "link": "https://www.thesportsdb.com/api/v1/json/1/eventspastleague.php?id={parameter1}",
            "parameter1": "league_name",
            "useful parameters": ["strEvent", "strEventAlternate", "strFilename", "strSport", "idLeague", "strLeague",
                                  "strSeason", "strDescriptionEN", "strHomeTeam", "strAwayTeam", "intHomeScore",
                                  "intRound", "intAwayScore", "intSpectators", "strOfficial", "strHomeGoalDetails",
                                  "strHomeRedCards", "strHomeYellowCards", "strHomeLineupGoalkeeper",
                                  "strHomeLineupDefense", "strHomeLineupMidfield", "strHomeLineupForward",
                                  "strHomeLineupSubstitutes", "strHomeFormation", "strAwayRedCards",
                                  "strAwayYellowCards", "strAwayGoalDetails", "strAwayLineupGoalkeeper",
                                  "strAwayLineupDefense", "strAwayLineupMidfield", "strAwayLineupForward",
                                  "strAwayLineupSubstitutes", "strAwayFormation", "intHomeShots", "intAwayShots",
                                  "strTimestamp", "dateEvent", "dateEventLocal", "strTime", "strTimeLocal",
                                  "strTVStation", "strResult", "strVenue", "strCountry", "strCity", "strPoster",
                                  "strSquare", "strFanart", "strThumb", "strBanner", "strMap", "strTweet1", "strTweet2",
                                  "strTweet3", "strVideo", "strStatus", "strPostponed"]
        }  # league ID-------------------------------------------------------------
}
"""

"""
options_need_id = ["List all Seasons in a League", "League Details", "Player Honours", "Player Former Teams",
                   "Player Contracts", "Lookup Table by League and Season", "Lookup Equipment by Team",
                   "Last 15 Events by League"]



from sportinf import constants
import requests
import json


class SportInfo:
    def __init__(self, **data):
        self.__data = data
        self.raw_info = self.__get_info()

    def __get_id(self):
        if self.__data["option"] in ["List all Seasons in a League", "League Details", "Lookup Table by League and Season", "Last 15 Events by League"]:
            r = requests.get("https://www.thesportsdb.com/api/v1/json/1/all_leagues.php")
            text = r.text
            leagues = json.loads(text)
            for league in leagues["leagues"]:
                if league["strLeague"] == self.__data["league_name"] or league["strLeagueAlternate"] == self.__data["league_name"]:
                    ID = league["idLeague"]
        elif self.__data["option"] in ["Player Honours", "Player Former Teams", "Player Contracts"]:  # player ID
            r = requests.get("https://www.thesportsdb.com/api/v1/json/1/searchplayers.php?p={}".format(self.__data["player_name"]))
            text = r.text
            player = json.loads(text)
            ID = player["player"][0]["idPlayer"]
        elif self.__data["option"] == "Lookup Equipment by Team":  # team ID # CHANGE HERE
            r = requests.get("https://www.thesportsdb.com/api/v1/json/1/searchteams.php?t={}".format(self.__data["team_name"]))
            text = r.text
            team = json.loads(text)
            ID = team["teams"][0]["idTeam"]
        elif self.__data["option"] == "Event Results":  # event ID =
            r = requests.get("https://www.thesportsdb.com/api/v1/json/1/searchevents.php?e={}".format(self.__data["event_name"]))
            text = r.text
            event = json.loads(text)
            ID = event["event"][0]["idEvent"]
        return ID

    def __replace_str_or_int(self, string):
        if "str" in string:
            edited_string = string.replace("str", "")
            return edited_string
        elif "int" in string:
            edited_string = string.replace("int", "")
            return edited_string
        else:
            return string

    def __get_info(self):
        link = constants.link_patterns[self.__data["option"]]["link"]
        opt = self.__data["option"]
        if self.__data["option"] in constants.options_need_id:
            need_id = self.__get_id()
            if self.__data["option"] == "Lookup Table by League and Season":
                name_of_second_parameter = constants.link_patterns[opt]["parameter2"]
                param2 = self.__data[name_of_second_parameter]
                try:
                    r = requests.get(link.format(parameter1=need_id, parameter2=param2))
                except requests.ConnectionError:
                    raise Exception("Check your Internet connection")
            else:
                try:
                    r = requests.get(link.format(parameter1=need_id))
                except requests.ConnectionError:
                    raise Exception("Check your Internet connection")

        elif self.__data["option"] in ["List all sports", "List all leagues", "List all countries"]:
            try:
                r = requests.get(link)
            except requests.ConnectionError:
                raise Exception("Check your Internet connection")
        else:
            name_of_parameter = constants.link_patterns[opt]["parameter1"]
            param1 = self.__data[name_of_parameter]
            try:
                r = requests.get(link.format(parameter1=param1))
            except requests.ConnectionError:
                raise Exception("Check your Internet connection")
        text = r.text
        info = json.loads(text)
        return info

    def __check_none_or_empty_value(self, value):
        if value is not None and value != "":
            return True
        else:
            return False

    def sport_info(self):
        useful_information = {}
        for general_value in self.raw_info.values():
            if general_value is None or general_value == "":
                raise Exception("Can`t find any information.\nPlease check your parameters")
            else:
                if len(general_value) >= 2:
                    for every_dictionary in general_value:
                        if self.__data["option"] == "Player Contracts":
                            contract_start = constants.link_patterns[self.__data["option"]]["useful parameters"][4]
                            contract_end = constants.link_patterns[self.__data["option"]]["useful parameters"][5]
                            unique_parameter = every_dictionary[contract_start] + " - " + every_dictionary[contract_end]
                        else:
                            name_of_unique_parameter = constants.link_patterns[self.__data["option"]]["useful parameters"][0]
                            unique_parameter = every_dictionary[name_of_unique_parameter]
                        useful_information[unique_parameter] = {}
                        for key, value in every_dictionary.items():
                            if key in constants.link_patterns[self.__data["option"]]["useful parameters"] and self.__check_none_or_empty_value(value):
                                useful_information[unique_parameter][self.__replace_str_or_int(key)] = value
                else:
                    for key, value in general_value[0].items():
                        if key in constants.link_patterns[self.__data["option"]]["useful parameters"] and self.__check_none_or_empty_value(value):
                            useful_information[self.__replace_str_or_int(key)] = value
        return useful_information



from setuptools import setup
import os

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='sportinf',
    version='1.1.2',
    long_description=long_description,
    packages=['tests', 'sportinf'],
    url='https://github.com/AlexBlackHawk/sportinf',
    license='MIT',
    author='alexm',
    author_email='alex.maudza@gmail.com',
    description='Package to get sport information',
    download_url='https://github.com/AlexBlackHawk/sportinf/archive/refs/tags/1.1.2.tar.gz',
    keywords=['sportinf', 'sport', 'scores', 'statistic'],
    install_requires=['requests'],
    python_requires='>=3'
)
